"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.phoneNumber = exports.alphaNumeric = exports.email = exports.minValue = exports.number = exports.minLength = exports.maxLength = exports.required = void 0;

var required = function required(value) {
  return value || value === 0 ? undefined : 'Campo obrigatório';
};

exports.required = required;

var maxLength = function maxLength(max) {
  return function (value) {
    return value && value.length > max ? "Campo deve conter ".concat(max, " caracteres ou menos") : undefined;
  };
};

exports.maxLength = maxLength;

var minLength = function minLength(min) {
  return function (value) {
    return value && value.length < min ? "Campo deve conter ".concat(min, " caracteres ou mais") : undefined;
  };
};

exports.minLength = minLength;

var number = function number(value) {
  return value && isNaN(Number(value)) ? 'Apenas números' : undefined;
};

exports.number = number;

var minValue = function minValue(min) {
  return function (value) {
    return value && value < min ? "Valor m\xEDnimo: ".concat(min) : undefined;
  };
};

exports.minValue = minValue;

var email = function email(value) {
  return value && !/^[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z]{2,4}$/i.test(value) ? 'Endereço de email inválido' : undefined;
};

exports.email = email;

var alphaNumeric = function alphaNumeric(value) {
  return value && /[^a-zA-Z0-9 ]/i.test(value) ? 'Apenas caracteres alfanuméricos' : undefined;
};

exports.alphaNumeric = alphaNumeric;

var phoneNumber = function phoneNumber(value) {
  return value && !/^(0|[1-9][0-9]{9})$/i.test(value) ? 'Telefone inválido' : undefined;
};

exports.phoneNumber = phoneNumber;